@@ -1,7 +1,7 @@
 package File::Random::Pick;
 
-our $DATE = '2015-11-23'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2019-09-15'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +49,7 @@ sub random_line {
 }
 
 1;
-# ABSTRACT: Pick random lines from a file
+# ABSTRACT: Pick random lines from a file, without duplicates
 
 __END__
 
@@ -59,11 +59,11 @@ __END__
 
 =head1 NAME
 
-File::Random::Pick - Pick random lines from a file
+File::Random::Pick - Pick random lines from a file, without duplicates
 
 =head1 VERSION
 
-This document describes version 0.02 of File::Random::Pick (from Perl distribution File-Random-Pick), released on 2015-11-23.
+This document describes version 0.03 of File::Random::Pick (from Perl distribution File-Random-Pick), released on 2019-09-15.
 
 =head1 SYNOPSIS
 
@@ -76,11 +76,12 @@ This document describes version 0.02 of File::Random::Pick (from Perl distributi
 
 =head1 DESCRIPTION
 
-This module can return random lines from a specified file.
+This module can return random lines from a specified file, without duplicates.
 
-Compared to the existing L<File::Random>, this module does not return
+Compared to C<random_line()> from L<File::Random>, this module does not return
 duplicates. I have also submitted a ticket to incorporate this functionality
-into File::Random [1]. It also accepts a filehandle, for convenience.
+into File::Random [1]. File::Random::Pick also accepts a filehandle, for
+convenience.
 
 =head1 FUNCTIONS
 
@@ -97,14 +98,6 @@ The algorithm used is from L<perlfaq> (C<perldoc -q "random line">), which scans
 the file once. The algorithm is for returning a single line and is modified to
 support returning multiple lines.
 
-=head1 SEE ALSO
-
-L<File::Random>
-
-L<File::RandomLine>
-
-[1] L<https://rt.cpan.org/Ticket/Display.html?id=109384>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/File-Random-Pick>.
@@ -121,13 +114,29 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<File::Random> also provides C<random_line()> which also uses a slightly
+modified version of the algorithm described in L<perlfaq> (C<perldoc -q "random
+line">) that avoids slurping the whole file into memory in exchange for scanning
+the whole file once. However, it might return duplicates.
+
+L<File::RandomLine>
+
+If you don't mind slurping the whole into memory, you can use
+L<List::MoreUtils>'s C<samples> to return N random items from a list. Or, if you
+also don't mind duplicates, you can just pick random elements from an array of
+lines.
+
+[1] L<https://rt.cpan.org/Ticket/Display.html?id=109384>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
